@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2020  The Software Heritage developers
+# Copyright (C) 2015-2021  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -7,41 +7,42 @@
 swh-storage.
 
 """
+from mmap import ACCESS_WRITE, mmap
 import os
 import pty
 import re
 import shutil
-import tempfile
-
-from mmap import mmap, ACCESS_WRITE
 from subprocess import Popen
-from typing import Dict, Iterator, List, Optional, Tuple
+import tempfile
+from typing import Any, Dict, Iterator, List, Optional, Tuple
 
-from swh.model import hashutil
+from subvertpy import SubversionException
+
+from swh.core.config import merge_configs
+from swh.loader.core.loader import BaseLoader
+from swh.loader.core.utils import clean_dangling_folders
+from swh.loader.exception import NotFound
+from swh.loader.svn.svn import SvnRepo
+from swh.model import from_disk, hashutil
 from swh.model.model import (
     Content,
     Directory,
     Origin,
-    SkippedContent,
     Revision,
+    SkippedContent,
     Snapshot,
     SnapshotBranch,
     TargetType,
 )
-from swh.model import from_disk
-from swh.loader.core.loader import BaseLoader
-from swh.loader.core.utils import clean_dangling_folders
 from swh.storage.algos.snapshot import snapshot_get_latest
 
-from . import svn, converters
+from . import converters
+from .exception import SvnLoaderHistoryAltered, SvnLoaderUneventful
 from .utils import (
-    init_svn_repo_from_dump,
-    init_svn_repo_from_archive_dump,
     OutputStream,
+    init_svn_repo_from_archive_dump,
+    init_svn_repo_from_dump,
 )
-from .exception import SvnLoaderUneventful
-from .exception import SvnLoaderHistoryAltered
-
 
 DEFAULT_BRANCH = b"HEAD"
 
@@ -49,6 +50,16 @@ DEFAULT_BRANCH = b"HEAD"
 TEMPORARY_DIR_PREFIX_PATTERN = "swh.loader.svn."
 
 
+DEFAULT_CONFIG: Dict[str, Any] = {
+    "temp_directory": "/tmp",
+    "debug": False,  # NOT FOR PRODUCTION: False for production
+    "check_revision": {
+        "status": False,  # True: check the revision, False: don't check
+        "limit": 1000,  # Periodicity check
+    },
+}
+
+
 class SvnLoader(BaseLoader):
     """Swh svn loader.
 
@@ -57,20 +68,6 @@ class SvnLoader(BaseLoader):
 
     """
 
-    CONFIG_BASE_FILENAME = "loader/svn"
-
-    ADDITIONAL_CONFIG = {
-        "temp_directory": ("str", "/tmp"),
-        "debug": ("bool", False),  # NOT FOR PRODUCTION, False for production
-        "check_revision": (
-            "dict",
-            {
-                "status": False,  # do we check the revision?
-                "limit": 1000,  # at which pace do we check it?
-            },
-        ),
-    }
-
     visit_type = "svn"
 
     def __init__(
@@ -83,6 +80,7 @@ class SvnLoader(BaseLoader):
         start_from_scratch=False,
     ):
         super().__init__(logging_class="swh.loader.svn.SvnLoader")
+        self.config = merge_configs(DEFAULT_CONFIG, self.config)
         # technical svn uri to act on svn repository
         self.svn_url = url
         # origin url as unique identifier for origin in swh archive
@@ -404,9 +402,20 @@ Local repository not cleaned up for investigation: %s"""
                 dir=self.temp_directory,
             )
 
-        self.svnrepo = svn.SvnRepo(
-            self.svn_url, self.origin_url, local_dirname, self.max_content_length
-        )
+        try:
+            self.svnrepo = SvnRepo(
+                self.svn_url, self.origin_url, local_dirname, self.max_content_length
+            )
+        except SubversionException as e:
+            error_msgs = [
+                "Unable to connect to a repository at URL",
+                "Unknown URL type",
+            ]
+            for msg in error_msgs:
+                if msg in e.args[0]:
+                    self._load_status = "uneventful"
+                    raise NotFound(e)
+            raise
 
         try:
             revision_start, revision_end, revision_parents = self.start_from(
